#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_MONE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_MONE_HPP_INCLUDED

#include <boost/simd/constant/include/constants/mone.hpp>

#endif
